@@ -1,16 +1,18 @@
 import hashlib
 import io
 import os
+import pathlib
 import pkg_resources
 import time
 
-import afmformats
+import afmformats.errors
 import nanite
 import nanite.fit as nfit
 import numpy as np
 from PyQt5 import uic, QtCore, QtGui, QtWidgets
 
 from .. import colormap
+from ..head.custom_widgets import show_wait_cursor
 
 from . import dlg_export_vals
 from . import export
@@ -33,6 +35,15 @@ class UiForceDistance(QtWidgets.QWidget):
         path_ui = pkg_resources.resource_filename("pyjibe.fd", "main.ui")
         uic.loadUi(path_ui, self)
 
+        self.settings = QtCore.QSettings()
+        self.settings.setIniCodec("utf-8")
+        if not self.settings.value("force-distance/rate ts path", ""):
+            dataloc = pathlib.Path(QtCore.QStandardPaths.writableLocation(
+                QtCore.QStandardPaths.AppDataLocation))
+            ts_import_path = dataloc / "force-distance_rate-ts-user"
+            self.settings.setValue("force-distance/rate ts path",
+                                   str(ts_import_path))
+
         UiForceDistance._instance_counter += 1
         title = "Force-Distance #{}".format(self._instance_counter)
         self.parent().setWindowTitle(title)
@@ -88,21 +99,73 @@ class UiForceDistance(QtWidgets.QWidget):
         # Filenames that were created by this instance
         self._autosave_original_files = []
 
+    def load_file(self, path, callback, user_metadata):
+        """Load a data file, optionally asking for missing metadata
+
+        Parameters
+        ----------
+        path: str or pathlib.Path
+            path to the data file
+        callback: callable
+            function for tracking loading progress
+        user_metadata: dict
+            dictionary holding the user-defined metadata; this
+            dictionary is edited in-place (i.e. the user only needs
+            to specify missing metadata once per import) if the
+            `user_metadata` is used consistently in an import loop
+            (like in `self.add_files`). Note that only the metadata
+            that is missing are used from user_metadata.
+        """
+        try:
+            grp = nanite.IndentationGroup(path, callback=callback)
+        except afmformats.errors.MissingMetaDataError as e:
+            custom_metadata = {}
+            for key in e.meta_keys:
+                # check if the keys are in user_metadata
+                if key not in user_metadata:
+                    # show dialog asking for missing metadata
+                    name, unit, _ = afmformats.meta.DEF_ALL[key]
+                    value, ok_pressed = QtWidgets.QInputDialog.getDouble(
+                        self,
+                        f"Missing metadata '{name}'",
+                        f"Please specify the {name}"
+                        + (f" [{unit}]" if unit else "")
+                        + ":",
+                        .0,
+                        .0,
+                        99999,
+                        12,
+                        )
+                    if not ok_pressed:
+                        # if user pressed cancel, raise AbortError
+                        raise AbortProgress(f"User did not enter {key}!")
+                    # add new keys in user_metadata
+                    user_metadata[key] = value
+                # populate custom_metadata with the user_metadata
+                custom_metadata[key] = user_metadata[key]
+            # now loading the data should work
+            grp = nanite.IndentationGroup(path,
+                                          callback=callback,
+                                          meta_override=custom_metadata)
+        return grp
+
     @property
     def current_curve(self):
+        """Indentation object of curve currently shown"""
         idx = self.current_index
         fdist = self.data_set[idx]
         return fdist
 
     @property
     def current_index(self):
+        """Index of curve currently shown"""
         item = self.list_curves.currentItem()
         idx = self.list_curves.indexOfTopLevelItem(item)
         return idx
 
     @property
     def selected_curves(self):
-        """Return an IndentationGroup with all curves selected by the user"""
+        """IndentationGroup with all curves selected by the user"""
         curves = nanite.IndentationGroup()
         for ar in self.data_set:
             idx = self.data_set.index(ar)
@@ -128,6 +191,7 @@ class UiForceDistance(QtWidgets.QWidget):
                                         "Stop", 1, len(files)*mult)
         bar.setWindowTitle("Loading data files")
         bar.setMinimumDuration(1000)
+        user_metadata = {}
         for ii, pp in enumerate(files):
             bar.setLabelText(f"Loading file\n{pp}")
 
@@ -150,12 +214,9 @@ class UiForceDistance(QtWidgets.QWidget):
                     # we can exit the parent for-loop.
                     raise AbortProgress
             try:
-                grp = nanite.IndentationGroup(pp, callback=callback)
-                callback(1)
-            except afmformats.errors.FileFormatMetaDataError:
-                # ignore e.g. JPK callibration curves
-                callback(1)
-                continue
+                grp = self.load_file(pp,
+                                     callback=callback,
+                                     user_metadata=user_metadata)
             except AbortProgress:
                 # The custom error `AbortProgress` was called, because
                 # the user wants to stop loading the data.
@@ -302,8 +363,9 @@ class UiForceDistance(QtWidgets.QWidget):
     @QtCore.pyqtSlot()
     def on_cb_rating_scheme(self):
         """Switch rating scheme or import a new one"""
+        rate_ts_path = self.settings.value("force-distance/rate ts path", "")
         scheme_id = self.cb_rating_scheme.currentIndex()
-        schemes = rating_base.get_rating_schemes()
+        schemes = rating_base.get_rating_schemes(rate_ts_path=rate_ts_path)
         if len(schemes) == scheme_id:
             search_dir = ""
             exts_str = "Training set zip file (*.zip)"
@@ -311,7 +373,9 @@ class UiForceDistance(QtWidgets.QWidget):
                 self.parent(), "Import a training set",
                 search_dir, exts_str)
             if tsz:
-                idx = rating_base.import_training_set(tsz)
+                idx = rating_base.import_training_set(
+                    ts_zip=tsz,
+                    rate_ts_path=rate_ts_path)
                 self.rating_scheme_setup()
                 self.cb_rating_scheme.setCurrentIndex(idx)
             else:
@@ -344,6 +408,7 @@ class UiForceDistance(QtWidgets.QWidget):
         self.autosave(fdist)
 
     @QtCore.pyqtSlot(QtCore.QModelIndex)
+    @show_wait_cursor
     def on_curve_list_item_changed(self, item):
         """An item in the curve list was changed
 
@@ -416,6 +481,7 @@ class UiForceDistance(QtWidgets.QWidget):
         dlg.show()
 
     @QtCore.pyqtSlot()
+    @show_wait_cursor
     def on_fit_all(self):
         """Apply initial parameters to all curves and fit"""
         # We will fit all curves with the currently visible settings
@@ -481,6 +547,7 @@ class UiForceDistance(QtWidgets.QWidget):
         self.tab_qmap.mpl_qmap_update()
 
     @QtCore.pyqtSlot()
+    @show_wait_cursor
     def on_rating_threshold(self):
         """(De)select curves according to threshold rating"""
         thresh = self.sp_rating_thresh.value()
@@ -500,8 +567,9 @@ class UiForceDistance(QtWidgets.QWidget):
         for fdist in self.data_set:
             self.autosave(fdist)
 
-    @QtCore.pyqtSlot(int)
-    def on_tab_changed(self, index):
+    @QtCore.pyqtSlot()
+    @show_wait_cursor
+    def on_tab_changed(self):
         """Called when the tab on the right hand is changed"""
         if hasattr(self, "user_tab_selected"):
             prevtab = self.user_tab_selected
@@ -515,10 +583,10 @@ class UiForceDistance(QtWidgets.QWidget):
             # Redraw the current map
             self.tab_qmap.mpl_qmap_update()
         elif curtab == self.tab_edelta:
-            # Compute edelta plot
+            # Compute e-delta plot
             self.tab_edelta.mpl_edelta_update()
         elif curtab == self.tab_info:
-            # Updat info (e.g. ancillaries)
+            # Update info (e.g. ancillaries)
             self.info_update()
 
         self.user_tab_selected = curtab
@@ -542,12 +610,16 @@ class UiForceDistance(QtWidgets.QWidget):
 
     def rate_data(self, data):
         """Apply rating to a force-distance curves (or a list of curves)"""
+        rate_ts_path = self.settings.value("force-distance/rate ts path", "")
         scheme_id = self.cb_rating_scheme.currentIndex()
-        return rating_base.rate_fdist(data, scheme_id)
+        return rating_base.rate_fdist(data=data,
+                                      scheme_id=scheme_id,
+                                      rate_ts_path=rate_ts_path)
 
     def rating_scheme_setup(self):
+        rate_ts_path = self.settings.value("force-distance/rate ts path", "")
         self.cb_rating_scheme.clear()
-        schemes = rating_base.get_rating_schemes()
+        schemes = rating_base.get_rating_schemes(rate_ts_path=rate_ts_path)
         self.cb_rating_scheme.addItems(list(schemes.keys()))
         self.cb_rating_scheme.addItem("Add...")
 
